Module geeny_api::models
[−]
[src]
API Data Models
These models are Rust equivalents of the models defined by the Geeny APIs. All types are serializable and deserializable using serde.
Structs
| AuthLoginRequest |
Structure for logging into the Geeny cloud via Basic Authentication |
| AuthLoginResponse |
Structure containing an API token from the Geeny cloud |
| GenericResponse |
Generic structure used for obtaining multiple items from the Geeny cloud |
| MessageType |
Structure representing a |
| MessageTypeRequest |
Structure for creating a new |
| MetaResponseInfo |
Generic structure used for obtaining multiple items from the Geeny cloud |
| RegistrationRequest |
Structure for creating a user account on the Geeny Cloud |
| Resource |
Structure representing a Resource on the Geeny cloud |
| Thing |
Structure represeting a Thing on the Geeny cloud |
| ThingCertificates |
Structure for storing certificates generated for a given Thing |
| ThingRequest |
Structure for creating a new Thing |
| ThingType |
Structure representing a |
| ThingTypeRequest |
Structure for creating a new |
Enums
| ResourceMethod |
Enumeration of possible methods of a Resource |